pub enum Core2dSystems {
Prepass,
MainPass,
EarlyPostProcess,
PostProcess,
}Expand description
System sets for the Core 2D rendering pipeline, defining the main stages of rendering. These stages include and run in the following order:
Prepass: Initial rendering operations, such as depth pre-pass.MainPass: The primary rendering operations, including drawing 2D sprites and meshes.EarlyPostProcess: Initial post processing effects.PostProcess: Final rendering operations, such as post-processing effects.
Additional systems can be added to these sets to customize the rendering pipeline, or additional sets can be created relative to these core sets.
Variants